# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class TeamMembersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_identity1(self, team_member_id, **kwargs):  # noqa: E501
        """Adds an identity to a team member  # noqa: E501

        _in snippets: platform.api.teamMembers.addIdentity_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_identity1(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param AddIdentityTeamMemberRequestModel body:
        :return: TeamMemberModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_identity1_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_identity1_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def add_identity1_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Adds an identity to a team member  # noqa: E501

        _in snippets: platform.api.teamMembers.addIdentity_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_identity1_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param AddIdentityTeamMemberRequestModel body:
        :return: TeamMemberModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_identity1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `add_identity1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/identity', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamMemberModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_team_member(self, **kwargs):  # noqa: E501
        """Creates a team member  # noqa: E501

        _in snippets: platform.api.teamMembers.addTeamMember_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_team_member(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddTeamMemberModel body:
        :return: TeamMemberModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_team_member_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_team_member_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_team_member_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a team member  # noqa: E501

        _in snippets: platform.api.teamMembers.addTeamMember_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_team_member_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddTeamMemberModel body:
        :return: TeamMemberModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_team_member" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamMemberModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_team_member(self, team_member_id, **kwargs):  # noqa: E501
        """Deletes a team member  # noqa: E501

        _in snippets: platform.api.teamMembers.deleteTeamMember_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_team_member(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_team_member_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_team_member_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def delete_team_member_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Deletes a team member  # noqa: E501

        _in snippets: platform.api.teamMembers.deleteTeamMember_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_team_member_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_team_member" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `delete_team_member`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_aggregate_permissions(self, team_member_id, **kwargs):  # noqa: E501
        """Gets a team member's permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.getAggregatePermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_aggregate_permissions(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_aggregate_permissions_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_aggregate_permissions_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_aggregate_permissions_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets a team member's permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.getAggregatePermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_aggregate_permissions_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_aggregate_permissions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_aggregate_permissions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/aggregate-permissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_org_channel_permission1(self, team_member_id, org_channel_id, permission, **kwargs):  # noqa: E501
        """Gets a team member's orgChannel permission  # noqa: E501

        _in snippets: platform.api.teamMembers.getOrgChannelPermission_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channel_permission1(team_member_id, org_channel_id, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int org_channel_id: (required)
        :param str permission: (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_org_channel_permission1_with_http_info(team_member_id, org_channel_id, permission, **kwargs)  # noqa: E501
        else:
            (data) = self.get_org_channel_permission1_with_http_info(team_member_id, org_channel_id, permission, **kwargs)  # noqa: E501
            return data

    def get_org_channel_permission1_with_http_info(self, team_member_id, org_channel_id, permission, **kwargs):  # noqa: E501
        """Gets a team member's orgChannel permission  # noqa: E501

        _in snippets: platform.api.teamMembers.getOrgChannelPermission_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channel_permission1_with_http_info(team_member_id, org_channel_id, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int org_channel_id: (required)
        :param str permission: (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'org_channel_id', 'permission']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_org_channel_permission1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_org_channel_permission1`")  # noqa: E501
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_org_channel_permission1`")  # noqa: E501
        # verify the required parameter 'permission' is set
        if ('permission' not in params or
                params['permission'] is None):
            raise ValueError("Missing the required parameter `permission` when calling `get_org_channel_permission1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501
        if 'permission' in params:
            path_params['permission'] = params['permission']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/org_channels/{orgChannelId}/permissions/{permission}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_org_channel_permissions1(self, team_member_id, org_channel_id, **kwargs):  # noqa: E501
        """Gets a team member's orgChannel permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.getOrgChannelPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channel_permissions1(team_member_id, org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int org_channel_id: (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_org_channel_permissions1_with_http_info(team_member_id, org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_org_channel_permissions1_with_http_info(team_member_id, org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_org_channel_permissions1_with_http_info(self, team_member_id, org_channel_id, **kwargs):  # noqa: E501
        """Gets a team member's orgChannel permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.getOrgChannelPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channel_permissions1_with_http_info(team_member_id, org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int org_channel_id: (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'org_channel_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_org_channel_permissions1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_org_channel_permissions1`")  # noqa: E501
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_org_channel_permissions1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/org_channels/{orgChannelId}/permissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_org_channels_with_permissions(self, team_member_id, **kwargs):  # noqa: E501
        """Gets the org channels a team member has permissions for  # noqa: E501

        _in snippets: platform.api.teamMembers.getOrgChannelsWithPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channels_with_permissions(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team_member_id: (required)
        :param int first:
        :param int max:
        :return: OrgChannelWithPermissionsModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_org_channels_with_permissions_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_org_channels_with_permissions_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_org_channels_with_permissions_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets the org channels a team member has permissions for  # noqa: E501

        _in snippets: platform.api.teamMembers.getOrgChannelsWithPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channels_with_permissions_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team_member_id: (required)
        :param int first:
        :param int max:
        :return: OrgChannelWithPermissionsModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_org_channels_with_permissions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_org_channels_with_permissions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/org_channels', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrgChannelWithPermissionsModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_permission1(self, team_member_id, permission, **kwargs):  # noqa: E501
        """Gets a team member's permission  # noqa: E501

        _in snippets: platform.api.teamMembers.getPermission_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_permission1(team_member_id, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param str permission: (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_permission1_with_http_info(team_member_id, permission, **kwargs)  # noqa: E501
        else:
            (data) = self.get_permission1_with_http_info(team_member_id, permission, **kwargs)  # noqa: E501
            return data

    def get_permission1_with_http_info(self, team_member_id, permission, **kwargs):  # noqa: E501
        """Gets a team member's permission  # noqa: E501

        _in snippets: platform.api.teamMembers.getPermission_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_permission1_with_http_info(team_member_id, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param str permission: (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'permission']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_permission1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_permission1`")  # noqa: E501
        # verify the required parameter 'permission' is set
        if ('permission' not in params or
                params['permission'] is None):
            raise ValueError("Missing the required parameter `permission` when calling `get_permission1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501
        if 'permission' in params:
            path_params['permission'] = params['permission']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/permissions/{permission}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_permissions1(self, team_member_id, **kwargs):  # noqa: E501
        """Gets a team member's permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.getPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_permissions1(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_permissions1_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_permissions1_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_permissions1_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets a team member's permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.getPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_permissions1_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_permissions1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_permissions1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/permissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_private_apps(self, team_member_id, **kwargs):  # noqa: E501
        """Installs private agent app for the given agent  # noqa: E501

        _in snippets: platform.api.teamMembers.getPrivateApps_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_private_apps(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_private_apps_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_private_apps_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_private_apps_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Installs private agent app for the given agent  # noqa: E501

        _in snippets: platform.api.teamMembers.getPrivateApps_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_private_apps_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_private_apps" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_private_apps`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/apps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[int]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_shared_apps(self, **kwargs):  # noqa: E501
        """Gets installed shared agent apps  # noqa: E501

        _in snippets: platform.api.teamMembers.getSharedApps_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shared_apps(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_shared_apps_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_shared_apps_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_shared_apps_with_http_info(self, **kwargs):  # noqa: E501
        """Gets installed shared agent apps  # noqa: E501

        _in snippets: platform.api.teamMembers.getSharedApps_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shared_apps_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_shared_apps" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/apps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[int]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_activity(self, **kwargs):  # noqa: E501
        """Returns a snapshot of team activity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_activity(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str start:
        :param str end:
        :param str group_id:
        :return: TeamActivityModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_activity_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_team_activity_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_team_activity_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a snapshot of team activity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_activity_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str start:
        :param str end:
        :param str group_id:
        :return: TeamActivityModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'end', 'group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_activity" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'end' in params:
            query_params.append(('end', params['end']))  # noqa: E501
        if 'group_id' in params:
            query_params.append(('groupId', params['group_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/activity', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamActivityModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_member(self, team_member_id, **kwargs):  # noqa: E501
        """Gets the details for a specific team member  # noqa: E501

        _in snippets: platform.api.teamMembers.getTeamMember_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: TeamMemberModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_member_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_team_member_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_team_member_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets the details for a specific team member  # noqa: E501

        _in snippets: platform.api.teamMembers.getTeamMember_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: TeamMemberModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_member" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_team_member`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamMemberModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_member_activity(self, team_member_id, **kwargs):  # noqa: E501
        """Returns a snapshot of a team members activity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_activity(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param str start:
        :param str end:
        :return: TeamActivityModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_member_activity_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_team_member_activity_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_team_member_activity_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Returns a snapshot of a team members activity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_activity_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param str start:
        :param str end:
        :return: TeamActivityModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'start', 'end']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_member_activity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_team_member_activity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'end' in params:
            query_params.append(('end', params['end']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/activity', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamActivityModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_member_notifications(self, team_member_id, **kwargs):  # noqa: E501
        """Gets a team member's notification settings  # noqa: E501

        _in snippets: platform.api.teamMembers.getTeamMemberNotifications_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_notifications(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: TeamMemberNotificationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_member_notifications_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_team_member_notifications_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_team_member_notifications_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets a team member's notification settings  # noqa: E501

        _in snippets: platform.api.teamMembers.getTeamMemberNotifications_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_notifications_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: TeamMemberNotificationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_member_notifications" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_team_member_notifications`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/notifications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamMemberNotificationModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_members(self, **kwargs):  # noqa: E501
        """Gets all the team members in the org  # noqa: E501

        _in snippets: platform.api.teamMembers.getTeamMembers_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_members(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :return: TeamMemberModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_members_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_team_members_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_team_members_with_http_info(self, **kwargs):  # noqa: E501
        """Gets all the team members in the org  # noqa: E501

        _in snippets: platform.api.teamMembers.getTeamMembers_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_members_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :return: TeamMemberModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_members" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamMemberModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def install_private_app(self, team_member_id, schema_id, **kwargs):  # noqa: E501
        """Installs private agent app for the given agent  # noqa: E501

        _in snippets: platform.api.teamMembers.installPrivateApp_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.install_private_app(team_member_id, schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int schema_id: (required)
        :param bool body:
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.install_private_app_with_http_info(team_member_id, schema_id, **kwargs)  # noqa: E501
        else:
            (data) = self.install_private_app_with_http_info(team_member_id, schema_id, **kwargs)  # noqa: E501
            return data

    def install_private_app_with_http_info(self, team_member_id, schema_id, **kwargs):  # noqa: E501
        """Installs private agent app for the given agent  # noqa: E501

        _in snippets: platform.api.teamMembers.installPrivateApp_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.install_private_app_with_http_info(team_member_id, schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int schema_id: (required)
        :param bool body:
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'schema_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method install_private_app" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `install_private_app`")  # noqa: E501
        # verify the required parameter 'schema_id' is set
        if ('schema_id' not in params or
                params['schema_id'] is None):
            raise ValueError("Missing the required parameter `schema_id` when calling `install_private_app`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501
        if 'schema_id' in params:
            path_params['schemaId'] = params['schema_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/apps/{schemaId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[int]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def install_shared_app(self, schema_id, **kwargs):  # noqa: E501
        """Installs shared agent app for all agents  # noqa: E501

        _in snippets: platform.api.teamMembers.installSharedApp_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.install_shared_app(schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int schema_id: (required)
        :param bool body:
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.install_shared_app_with_http_info(schema_id, **kwargs)  # noqa: E501
        else:
            (data) = self.install_shared_app_with_http_info(schema_id, **kwargs)  # noqa: E501
            return data

    def install_shared_app_with_http_info(self, schema_id, **kwargs):  # noqa: E501
        """Installs shared agent app for all agents  # noqa: E501

        _in snippets: platform.api.teamMembers.installSharedApp_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.install_shared_app_with_http_info(schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int schema_id: (required)
        :param bool body:
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['schema_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method install_shared_app" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'schema_id' is set
        if ('schema_id' not in params or
                params['schema_id'] is None):
            raise ValueError("Missing the required parameter `schema_id` when calling `install_shared_app`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'schema_id' in params:
            path_params['schemaId'] = params['schema_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/apps/{schemaId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[int]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_org_channel_permission(self, team_member_id, org_channel_id, permission, **kwargs):  # noqa: E501
        """Sets a team member's orgChannel permission  # noqa: E501

        _in snippets: platform.api.teamMembers.setOrgChannelPermission_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_org_channel_permission(team_member_id, org_channel_id, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int org_channel_id: (required)
        :param str permission: (required)
        :param bool body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_org_channel_permission_with_http_info(team_member_id, org_channel_id, permission, **kwargs)  # noqa: E501
        else:
            (data) = self.set_org_channel_permission_with_http_info(team_member_id, org_channel_id, permission, **kwargs)  # noqa: E501
            return data

    def set_org_channel_permission_with_http_info(self, team_member_id, org_channel_id, permission, **kwargs):  # noqa: E501
        """Sets a team member's orgChannel permission  # noqa: E501

        _in snippets: platform.api.teamMembers.setOrgChannelPermission_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_org_channel_permission_with_http_info(team_member_id, org_channel_id, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int org_channel_id: (required)
        :param str permission: (required)
        :param bool body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'org_channel_id', 'permission', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_org_channel_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `set_org_channel_permission`")  # noqa: E501
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `set_org_channel_permission`")  # noqa: E501
        # verify the required parameter 'permission' is set
        if ('permission' not in params or
                params['permission'] is None):
            raise ValueError("Missing the required parameter `permission` when calling `set_org_channel_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501
        if 'permission' in params:
            path_params['permission'] = params['permission']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/org_channels/{orgChannelId}/permissions/{permission}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_org_channel_permissions1(self, team_member_id, org_channel_id, **kwargs):  # noqa: E501
        """Sets a team member's orgChannel permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.setOrgChannelPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_org_channel_permissions1(team_member_id, org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int org_channel_id: (required)
        :param list[str] body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_org_channel_permissions1_with_http_info(team_member_id, org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_org_channel_permissions1_with_http_info(team_member_id, org_channel_id, **kwargs)  # noqa: E501
            return data

    def set_org_channel_permissions1_with_http_info(self, team_member_id, org_channel_id, **kwargs):  # noqa: E501
        """Sets a team member's orgChannel permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.setOrgChannelPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_org_channel_permissions1_with_http_info(team_member_id, org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param int org_channel_id: (required)
        :param list[str] body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'org_channel_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_org_channel_permissions1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `set_org_channel_permissions1`")  # noqa: E501
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `set_org_channel_permissions1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/org_channels/{orgChannelId}/permissions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_permission(self, team_member_id, permission, **kwargs):  # noqa: E501
        """Sets a team member's permission  # noqa: E501

        _in snippets: platform.api.teamMembers.setPermission_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_permission(team_member_id, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param str permission: (required)
        :param bool body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_permission_with_http_info(team_member_id, permission, **kwargs)  # noqa: E501
        else:
            (data) = self.set_permission_with_http_info(team_member_id, permission, **kwargs)  # noqa: E501
            return data

    def set_permission_with_http_info(self, team_member_id, permission, **kwargs):  # noqa: E501
        """Sets a team member's permission  # noqa: E501

        _in snippets: platform.api.teamMembers.setPermission_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_permission_with_http_info(team_member_id, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param str permission: (required)
        :param bool body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'permission', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `set_permission`")  # noqa: E501
        # verify the required parameter 'permission' is set
        if ('permission' not in params or
                params['permission'] is None):
            raise ValueError("Missing the required parameter `permission` when calling `set_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501
        if 'permission' in params:
            path_params['permission'] = params['permission']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/permissions/{permission}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_permissions1(self, team_member_id, **kwargs):  # noqa: E501
        """Sets a team member's permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.setPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_permissions1(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param list[str] body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_permissions1_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_permissions1_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def set_permissions1_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Sets a team member's permissions  # noqa: E501

        _in snippets: platform.api.teamMembers.setPermissions_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_permissions1_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param list[str] body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_permissions1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `set_permissions1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/permissions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_team_member_notifications(self, team_member_id, **kwargs):  # noqa: E501
        """Sets a team member's notification settings  # noqa: E501

        _in snippets: platform.api.teamMembers.setTeamMemberNotifications_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_team_member_notifications(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param TeamMemberNotificationModel body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_team_member_notifications_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_team_member_notifications_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def set_team_member_notifications_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Sets a team member's notification settings  # noqa: E501

        _in snippets: platform.api.teamMembers.setTeamMemberNotifications_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_team_member_notifications_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param TeamMemberNotificationModel body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_team_member_notifications" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `set_team_member_notifications`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}/notifications', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_team_member(self, team_member_id, **kwargs):  # noqa: E501
        """Updates a team member  # noqa: E501

        _in snippets: platform.api.teamMembers.updateTeamMember_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_team_member(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param UpdateTeamMemberRequestModel body:
        :return: TeamMemberModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_team_member_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_team_member_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def update_team_member_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Updates a team member  # noqa: E501

        _in snippets: platform.api.teamMembers.updateTeamMember_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_team_member_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :param UpdateTeamMemberRequestModel body:
        :return: TeamMemberModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_team_member" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `update_team_member`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/{teamMemberId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamMemberModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_file_to_team_members(self, team_member_ids, **kwargs):  # noqa: E501
        """Upload a file for specific team member(s) to access  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file_to_team_members(team_member_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[int] team_member_ids: The file to to upload. (required)
        :param str file:
        :return: TeamMemberFileModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_file_to_team_members_with_http_info(team_member_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_file_to_team_members_with_http_info(team_member_ids, **kwargs)  # noqa: E501
            return data

    def upload_file_to_team_members_with_http_info(self, team_member_ids, **kwargs):  # noqa: E501
        """Upload a file for specific team member(s) to access  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file_to_team_members_with_http_info(team_member_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[int] team_member_ids: The file to to upload. (required)
        :param str file:
        :return: TeamMemberFileModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_ids', 'file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_file_to_team_members" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_ids' is set
        if ('team_member_ids' not in params or
                params['team_member_ids'] is None):
            raise ValueError("Missing the required parameter `team_member_ids` when calling `upload_file_to_team_members`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'team_member_ids' in params:
            query_params.append(('teamMemberIds', params['team_member_ids']))  # noqa: E501
            collection_formats['teamMemberIds'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/team_members/upload', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamMemberFileModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BulkActionPerformActionModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'add_tags': 'list[TagModel]',
        'remove_tags': 'list[str]',
        'set_global_opt_out': 'bool',
        'clear_global_opt_out': 'bool',
        'status': 'str',
        'search_value': 'str',
        'team_member_id': 'int',
        'variant_id': 'int'
    }

    attribute_map = {
        'add_tags': 'addTags',
        'remove_tags': 'removeTags',
        'set_global_opt_out': 'setGlobalOptOut',
        'clear_global_opt_out': 'clearGlobalOptOut',
        'status': 'status',
        'search_value': 'searchValue',
        'team_member_id': 'teamMemberId',
        'variant_id': 'variantId'
    }

    def __init__(self, add_tags=None, remove_tags=None, set_global_opt_out=None, clear_global_opt_out=None, status=None, search_value=None, team_member_id=None, variant_id=None):  # noqa: E501
        """BulkActionPerformActionModel - a model defined in Swagger"""  # noqa: E501
        self._add_tags = None
        self._remove_tags = None
        self._set_global_opt_out = None
        self._clear_global_opt_out = None
        self._status = None
        self._search_value = None
        self._team_member_id = None
        self._variant_id = None
        self.discriminator = None
        if add_tags is not None:
            self.add_tags = add_tags
        if remove_tags is not None:
            self.remove_tags = remove_tags
        if set_global_opt_out is not None:
            self.set_global_opt_out = set_global_opt_out
        if clear_global_opt_out is not None:
            self.clear_global_opt_out = clear_global_opt_out
        if status is not None:
            self.status = status
        if search_value is not None:
            self.search_value = search_value
        if team_member_id is not None:
            self.team_member_id = team_member_id
        if variant_id is not None:
            self.variant_id = variant_id

    @property
    def add_tags(self):
        """Gets the add_tags of this BulkActionPerformActionModel.  # noqa: E501

        Tags to add to the contacts  # noqa: E501

        :return: The add_tags of this BulkActionPerformActionModel.  # noqa: E501
        :rtype: list[TagModel]
        """
        return self._add_tags

    @add_tags.setter
    def add_tags(self, add_tags):
        """Sets the add_tags of this BulkActionPerformActionModel.

        Tags to add to the contacts  # noqa: E501

        :param add_tags: The add_tags of this BulkActionPerformActionModel.  # noqa: E501
        :type: list[TagModel]
        """

        self._add_tags = add_tags

    @property
    def remove_tags(self):
        """Gets the remove_tags of this BulkActionPerformActionModel.  # noqa: E501

        Tags to remove from the contacts  # noqa: E501

        :return: The remove_tags of this BulkActionPerformActionModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._remove_tags

    @remove_tags.setter
    def remove_tags(self, remove_tags):
        """Sets the remove_tags of this BulkActionPerformActionModel.

        Tags to remove from the contacts  # noqa: E501

        :param remove_tags: The remove_tags of this BulkActionPerformActionModel.  # noqa: E501
        :type: list[str]
        """

        self._remove_tags = remove_tags

    @property
    def set_global_opt_out(self):
        """Gets the set_global_opt_out of this BulkActionPerformActionModel.  # noqa: E501

        Globally opt out the contacts  # noqa: E501

        :return: The set_global_opt_out of this BulkActionPerformActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._set_global_opt_out

    @set_global_opt_out.setter
    def set_global_opt_out(self, set_global_opt_out):
        """Sets the set_global_opt_out of this BulkActionPerformActionModel.

        Globally opt out the contacts  # noqa: E501

        :param set_global_opt_out: The set_global_opt_out of this BulkActionPerformActionModel.  # noqa: E501
        :type: bool
        """

        self._set_global_opt_out = set_global_opt_out

    @property
    def clear_global_opt_out(self):
        """Gets the clear_global_opt_out of this BulkActionPerformActionModel.  # noqa: E501

        Remove the global opt out for the contacts  # noqa: E501

        :return: The clear_global_opt_out of this BulkActionPerformActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._clear_global_opt_out

    @clear_global_opt_out.setter
    def clear_global_opt_out(self, clear_global_opt_out):
        """Sets the clear_global_opt_out of this BulkActionPerformActionModel.

        Remove the global opt out for the contacts  # noqa: E501

        :param clear_global_opt_out: The clear_global_opt_out of this BulkActionPerformActionModel.  # noqa: E501
        :type: bool
        """

        self._clear_global_opt_out = clear_global_opt_out

    @property
    def status(self):
        """Gets the status of this BulkActionPerformActionModel.  # noqa: E501

        Contact status to filter on  # noqa: E501

        :return: The status of this BulkActionPerformActionModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BulkActionPerformActionModel.

        Contact status to filter on  # noqa: E501

        :param status: The status of this BulkActionPerformActionModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["ALL", "DELIVERED", "SKIPPED", "QUEUED", "LOCKED", "CANCELLED", "ERRORED", "ENGAGED_INSTANT_APP_OPENED", "ENGAGED_SMART_LINK_CLICKED", "ENGAGED_REPLIED", "ENGAGED_REPLIED_TO_REPLY", "NO_RESPONSE", "OPT_OUT", "RESOLUTION", "ERROR", "ADDED_TAG", "PROCESSING_PENDING"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def search_value(self):
        """Gets the search_value of this BulkActionPerformActionModel.  # noqa: E501

        Additional search value depending on the status  # noqa: E501

        :return: The search_value of this BulkActionPerformActionModel.  # noqa: E501
        :rtype: str
        """
        return self._search_value

    @search_value.setter
    def search_value(self, search_value):
        """Sets the search_value of this BulkActionPerformActionModel.

        Additional search value depending on the status  # noqa: E501

        :param search_value: The search_value of this BulkActionPerformActionModel.  # noqa: E501
        :type: str
        """

        self._search_value = search_value

    @property
    def team_member_id(self):
        """Gets the team_member_id of this BulkActionPerformActionModel.  # noqa: E501

        Team Member to filter on for P2P broadcasts  # noqa: E501

        :return: The team_member_id of this BulkActionPerformActionModel.  # noqa: E501
        :rtype: int
        """
        return self._team_member_id

    @team_member_id.setter
    def team_member_id(self, team_member_id):
        """Sets the team_member_id of this BulkActionPerformActionModel.

        Team Member to filter on for P2P broadcasts  # noqa: E501

        :param team_member_id: The team_member_id of this BulkActionPerformActionModel.  # noqa: E501
        :type: int
        """

        self._team_member_id = team_member_id

    @property
    def variant_id(self):
        """Gets the variant_id of this BulkActionPerformActionModel.  # noqa: E501

        Id of variant to filter on if the broadcast was using A/B Testing  # noqa: E501

        :return: The variant_id of this BulkActionPerformActionModel.  # noqa: E501
        :rtype: int
        """
        return self._variant_id

    @variant_id.setter
    def variant_id(self, variant_id):
        """Sets the variant_id of this BulkActionPerformActionModel.

        Id of variant to filter on if the broadcast was using A/B Testing  # noqa: E501

        :param variant_id: The variant_id of this BulkActionPerformActionModel.  # noqa: E501
        :type: int
        """

        self._variant_id = variant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BulkActionPerformActionModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulkActionPerformActionModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsKpiReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp_epoch': 'int',
        'engagement_report': 'AnalyticsCustomerEngagementReportModel',
        'messaging_report': 'AnalyticsMessagingReportListItemModel',
        'bulk_action_report': 'AnalyticsBulkActionReportModel',
        'instant_app_report': 'AnalyticsInstantAppReportModel',
        'error_report': 'AnalyticsErrorReportModel',
        'api_report': 'AnalyticsApiReportModel'
    }

    attribute_map = {
        'timestamp_epoch': 'timestampEpoch',
        'engagement_report': 'engagementReport',
        'messaging_report': 'messagingReport',
        'bulk_action_report': 'bulkActionReport',
        'instant_app_report': 'instantAppReport',
        'error_report': 'errorReport',
        'api_report': 'apiReport'
    }

    def __init__(self, timestamp_epoch=None, engagement_report=None, messaging_report=None, bulk_action_report=None, instant_app_report=None, error_report=None, api_report=None):  # noqa: E501
        """AnalyticsKpiReportModel - a model defined in Swagger"""  # noqa: E501
        self._timestamp_epoch = None
        self._engagement_report = None
        self._messaging_report = None
        self._bulk_action_report = None
        self._instant_app_report = None
        self._error_report = None
        self._api_report = None
        self.discriminator = None
        if timestamp_epoch is not None:
            self.timestamp_epoch = timestamp_epoch
        if engagement_report is not None:
            self.engagement_report = engagement_report
        if messaging_report is not None:
            self.messaging_report = messaging_report
        if bulk_action_report is not None:
            self.bulk_action_report = bulk_action_report
        if instant_app_report is not None:
            self.instant_app_report = instant_app_report
        if error_report is not None:
            self.error_report = error_report
        if api_report is not None:
            self.api_report = api_report

    @property
    def timestamp_epoch(self):
        """Gets the timestamp_epoch of this AnalyticsKpiReportModel.  # noqa: E501

        The timestamp at the start of the default group-by window as a Unix timestamp.  # noqa: E501

        :return: The timestamp_epoch of this AnalyticsKpiReportModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp_epoch

    @timestamp_epoch.setter
    def timestamp_epoch(self, timestamp_epoch):
        """Sets the timestamp_epoch of this AnalyticsKpiReportModel.

        The timestamp at the start of the default group-by window as a Unix timestamp.  # noqa: E501

        :param timestamp_epoch: The timestamp_epoch of this AnalyticsKpiReportModel.  # noqa: E501
        :type: int
        """

        self._timestamp_epoch = timestamp_epoch

    @property
    def engagement_report(self):
        """Gets the engagement_report of this AnalyticsKpiReportModel.  # noqa: E501


        :return: The engagement_report of this AnalyticsKpiReportModel.  # noqa: E501
        :rtype: AnalyticsCustomerEngagementReportModel
        """
        return self._engagement_report

    @engagement_report.setter
    def engagement_report(self, engagement_report):
        """Sets the engagement_report of this AnalyticsKpiReportModel.


        :param engagement_report: The engagement_report of this AnalyticsKpiReportModel.  # noqa: E501
        :type: AnalyticsCustomerEngagementReportModel
        """

        self._engagement_report = engagement_report

    @property
    def messaging_report(self):
        """Gets the messaging_report of this AnalyticsKpiReportModel.  # noqa: E501


        :return: The messaging_report of this AnalyticsKpiReportModel.  # noqa: E501
        :rtype: AnalyticsMessagingReportListItemModel
        """
        return self._messaging_report

    @messaging_report.setter
    def messaging_report(self, messaging_report):
        """Sets the messaging_report of this AnalyticsKpiReportModel.


        :param messaging_report: The messaging_report of this AnalyticsKpiReportModel.  # noqa: E501
        :type: AnalyticsMessagingReportListItemModel
        """

        self._messaging_report = messaging_report

    @property
    def bulk_action_report(self):
        """Gets the bulk_action_report of this AnalyticsKpiReportModel.  # noqa: E501


        :return: The bulk_action_report of this AnalyticsKpiReportModel.  # noqa: E501
        :rtype: AnalyticsBulkActionReportModel
        """
        return self._bulk_action_report

    @bulk_action_report.setter
    def bulk_action_report(self, bulk_action_report):
        """Sets the bulk_action_report of this AnalyticsKpiReportModel.


        :param bulk_action_report: The bulk_action_report of this AnalyticsKpiReportModel.  # noqa: E501
        :type: AnalyticsBulkActionReportModel
        """

        self._bulk_action_report = bulk_action_report

    @property
    def instant_app_report(self):
        """Gets the instant_app_report of this AnalyticsKpiReportModel.  # noqa: E501


        :return: The instant_app_report of this AnalyticsKpiReportModel.  # noqa: E501
        :rtype: AnalyticsInstantAppReportModel
        """
        return self._instant_app_report

    @instant_app_report.setter
    def instant_app_report(self, instant_app_report):
        """Sets the instant_app_report of this AnalyticsKpiReportModel.


        :param instant_app_report: The instant_app_report of this AnalyticsKpiReportModel.  # noqa: E501
        :type: AnalyticsInstantAppReportModel
        """

        self._instant_app_report = instant_app_report

    @property
    def error_report(self):
        """Gets the error_report of this AnalyticsKpiReportModel.  # noqa: E501


        :return: The error_report of this AnalyticsKpiReportModel.  # noqa: E501
        :rtype: AnalyticsErrorReportModel
        """
        return self._error_report

    @error_report.setter
    def error_report(self, error_report):
        """Sets the error_report of this AnalyticsKpiReportModel.


        :param error_report: The error_report of this AnalyticsKpiReportModel.  # noqa: E501
        :type: AnalyticsErrorReportModel
        """

        self._error_report = error_report

    @property
    def api_report(self):
        """Gets the api_report of this AnalyticsKpiReportModel.  # noqa: E501


        :return: The api_report of this AnalyticsKpiReportModel.  # noqa: E501
        :rtype: AnalyticsApiReportModel
        """
        return self._api_report

    @api_report.setter
    def api_report(self, api_report):
        """Sets the api_report of this AnalyticsKpiReportModel.


        :param api_report: The api_report of this AnalyticsKpiReportModel.  # noqa: E501
        :type: AnalyticsApiReportModel
        """

        self._api_report = api_report

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsKpiReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsKpiReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ConversationModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'org_channel_id': 'int',
        'customer_channel_id': 'int',
        'created_timestamp': 'int',
        'last_updated_timestamp': 'int',
        'conversation_members': 'list[ConversationMemberModel]',
        'conversation_bots': 'list[ConversationBotModel]',
        'status': 'str',
        'first_customer_message': 'MessageModel',
        'topic': 'str'
    }

    attribute_map = {
        'id': 'id',
        'org_channel_id': 'orgChannelId',
        'customer_channel_id': 'customerChannelId',
        'created_timestamp': 'createdTimestamp',
        'last_updated_timestamp': 'lastUpdatedTimestamp',
        'conversation_members': 'conversationMembers',
        'conversation_bots': 'conversationBots',
        'status': 'status',
        'first_customer_message': 'firstCustomerMessage',
        'topic': 'topic'
    }

    def __init__(self, id=None, org_channel_id=None, customer_channel_id=None, created_timestamp=None, last_updated_timestamp=None, conversation_members=None, conversation_bots=None, status=None, first_customer_message=None, topic=None):  # noqa: E501
        """ConversationModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._org_channel_id = None
        self._customer_channel_id = None
        self._created_timestamp = None
        self._last_updated_timestamp = None
        self._conversation_members = None
        self._conversation_bots = None
        self._status = None
        self._first_customer_message = None
        self._topic = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if org_channel_id is not None:
            self.org_channel_id = org_channel_id
        if customer_channel_id is not None:
            self.customer_channel_id = customer_channel_id
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if last_updated_timestamp is not None:
            self.last_updated_timestamp = last_updated_timestamp
        if conversation_members is not None:
            self.conversation_members = conversation_members
        if conversation_bots is not None:
            self.conversation_bots = conversation_bots
        if status is not None:
            self.status = status
        if first_customer_message is not None:
            self.first_customer_message = first_customer_message
        if topic is not None:
            self.topic = topic

    @property
    def id(self):
        """Gets the id of this ConversationModel.  # noqa: E501


        :return: The id of this ConversationModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConversationModel.


        :param id: The id of this ConversationModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def org_channel_id(self):
        """Gets the org_channel_id of this ConversationModel.  # noqa: E501


        :return: The org_channel_id of this ConversationModel.  # noqa: E501
        :rtype: int
        """
        return self._org_channel_id

    @org_channel_id.setter
    def org_channel_id(self, org_channel_id):
        """Sets the org_channel_id of this ConversationModel.


        :param org_channel_id: The org_channel_id of this ConversationModel.  # noqa: E501
        :type: int
        """

        self._org_channel_id = org_channel_id

    @property
    def customer_channel_id(self):
        """Gets the customer_channel_id of this ConversationModel.  # noqa: E501


        :return: The customer_channel_id of this ConversationModel.  # noqa: E501
        :rtype: int
        """
        return self._customer_channel_id

    @customer_channel_id.setter
    def customer_channel_id(self, customer_channel_id):
        """Sets the customer_channel_id of this ConversationModel.


        :param customer_channel_id: The customer_channel_id of this ConversationModel.  # noqa: E501
        :type: int
        """

        self._customer_channel_id = customer_channel_id

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this ConversationModel.  # noqa: E501


        :return: The created_timestamp of this ConversationModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this ConversationModel.


        :param created_timestamp: The created_timestamp of this ConversationModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def last_updated_timestamp(self):
        """Gets the last_updated_timestamp of this ConversationModel.  # noqa: E501


        :return: The last_updated_timestamp of this ConversationModel.  # noqa: E501
        :rtype: int
        """
        return self._last_updated_timestamp

    @last_updated_timestamp.setter
    def last_updated_timestamp(self, last_updated_timestamp):
        """Sets the last_updated_timestamp of this ConversationModel.


        :param last_updated_timestamp: The last_updated_timestamp of this ConversationModel.  # noqa: E501
        :type: int
        """

        self._last_updated_timestamp = last_updated_timestamp

    @property
    def conversation_members(self):
        """Gets the conversation_members of this ConversationModel.  # noqa: E501


        :return: The conversation_members of this ConversationModel.  # noqa: E501
        :rtype: list[ConversationMemberModel]
        """
        return self._conversation_members

    @conversation_members.setter
    def conversation_members(self, conversation_members):
        """Sets the conversation_members of this ConversationModel.


        :param conversation_members: The conversation_members of this ConversationModel.  # noqa: E501
        :type: list[ConversationMemberModel]
        """

        self._conversation_members = conversation_members

    @property
    def conversation_bots(self):
        """Gets the conversation_bots of this ConversationModel.  # noqa: E501


        :return: The conversation_bots of this ConversationModel.  # noqa: E501
        :rtype: list[ConversationBotModel]
        """
        return self._conversation_bots

    @conversation_bots.setter
    def conversation_bots(self, conversation_bots):
        """Sets the conversation_bots of this ConversationModel.


        :param conversation_bots: The conversation_bots of this ConversationModel.  # noqa: E501
        :type: list[ConversationBotModel]
        """

        self._conversation_bots = conversation_bots

    @property
    def status(self):
        """Gets the status of this ConversationModel.  # noqa: E501


        :return: The status of this ConversationModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ConversationModel.


        :param status: The status of this ConversationModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["PENDING", "UNASSIGNED", "QUEUED", "ACTIVE", "COMPLETE"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def first_customer_message(self):
        """Gets the first_customer_message of this ConversationModel.  # noqa: E501


        :return: The first_customer_message of this ConversationModel.  # noqa: E501
        :rtype: MessageModel
        """
        return self._first_customer_message

    @first_customer_message.setter
    def first_customer_message(self, first_customer_message):
        """Sets the first_customer_message of this ConversationModel.


        :param first_customer_message: The first_customer_message of this ConversationModel.  # noqa: E501
        :type: MessageModel
        """

        self._first_customer_message = first_customer_message

    @property
    def topic(self):
        """Gets the topic of this ConversationModel.  # noqa: E501


        :return: The topic of this ConversationModel.  # noqa: E501
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """Sets the topic of this ConversationModel.


        :param topic: The topic of this ConversationModel.  # noqa: E501
        :type: str
        """

        self._topic = topic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConversationModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConversationModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InstantAppModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'created_timestamp': 'int',
        'customer_url': 'str',
        'status': 'str',
        'schema_api_id': 'str',
        'parameters': 'list[Parameter]'
    }

    attribute_map = {
        'id': 'id',
        'created_timestamp': 'createdTimestamp',
        'customer_url': 'customerUrl',
        'status': 'status',
        'schema_api_id': 'schemaApiId',
        'parameters': 'parameters'
    }

    def __init__(self, id=None, created_timestamp=None, customer_url=None, status=None, schema_api_id=None, parameters=None):  # noqa: E501
        """InstantAppModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_timestamp = None
        self._customer_url = None
        self._status = None
        self._schema_api_id = None
        self._parameters = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if customer_url is not None:
            self.customer_url = customer_url
        if status is not None:
            self.status = status
        self.schema_api_id = schema_api_id
        if parameters is not None:
            self.parameters = parameters

    @property
    def id(self):
        """Gets the id of this InstantAppModel.  # noqa: E501

        The system generated unique id for this Instant App.  # noqa: E501

        :return: The id of this InstantAppModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InstantAppModel.

        The system generated unique id for this Instant App.  # noqa: E501

        :param id: The id of this InstantAppModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this InstantAppModel.  # noqa: E501

        The time the Instant App was created.  # noqa: E501

        :return: The created_timestamp of this InstantAppModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this InstantAppModel.

        The time the Instant App was created.  # noqa: E501

        :param created_timestamp: The created_timestamp of this InstantAppModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def customer_url(self):
        """Gets the customer_url of this InstantAppModel.  # noqa: E501

        The URL for the customer to view and interact with the Instant App.  # noqa: E501

        :return: The customer_url of this InstantAppModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_url

    @customer_url.setter
    def customer_url(self, customer_url):
        """Sets the customer_url of this InstantAppModel.

        The URL for the customer to view and interact with the Instant App.  # noqa: E501

        :param customer_url: The customer_url of this InstantAppModel.  # noqa: E501
        :type: str
        """

        self._customer_url = customer_url

    @property
    def status(self):
        """Gets the status of this InstantAppModel.  # noqa: E501

        The status for this Instant App.  # noqa: E501

        :return: The status of this InstantAppModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InstantAppModel.

        The status for this Instant App.  # noqa: E501

        :param status: The status of this InstantAppModel.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def schema_api_id(self):
        """Gets the schema_api_id of this InstantAppModel.  # noqa: E501

        The programmatic, unique id of the schema for this instant app.  # noqa: E501

        :return: The schema_api_id of this InstantAppModel.  # noqa: E501
        :rtype: str
        """
        return self._schema_api_id

    @schema_api_id.setter
    def schema_api_id(self, schema_api_id):
        """Sets the schema_api_id of this InstantAppModel.

        The programmatic, unique id of the schema for this instant app.  # noqa: E501

        :param schema_api_id: The schema_api_id of this InstantAppModel.  # noqa: E501
        :type: str
        """
        if schema_api_id is None:
            raise ValueError("Invalid value for `schema_api_id`, must not be `None`")  # noqa: E501

        self._schema_api_id = schema_api_id

    @property
    def parameters(self):
        """Gets the parameters of this InstantAppModel.  # noqa: E501


        :return: The parameters of this InstantAppModel.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this InstantAppModel.


        :param parameters: The parameters of this InstantAppModel.  # noqa: E501
        :type: list[Parameter]
        """

        self._parameters = parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstantAppModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstantAppModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsMessagingReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'messaging_report': 'list[AnalyticsMessagingReportListItemModel]',
        'unique_active_customers': 'int',
        'unique_active_channels': 'int',
        'unique_active_agents': 'int'
    }

    attribute_map = {
        'messaging_report': 'messagingReport',
        'unique_active_customers': 'uniqueActiveCustomers',
        'unique_active_channels': 'uniqueActiveChannels',
        'unique_active_agents': 'uniqueActiveAgents'
    }

    def __init__(self, messaging_report=None, unique_active_customers=None, unique_active_channels=None, unique_active_agents=None):  # noqa: E501
        """AnalyticsMessagingReportModel - a model defined in Swagger"""  # noqa: E501
        self._messaging_report = None
        self._unique_active_customers = None
        self._unique_active_channels = None
        self._unique_active_agents = None
        self.discriminator = None
        if messaging_report is not None:
            self.messaging_report = messaging_report
        if unique_active_customers is not None:
            self.unique_active_customers = unique_active_customers
        if unique_active_channels is not None:
            self.unique_active_channels = unique_active_channels
        if unique_active_agents is not None:
            self.unique_active_agents = unique_active_agents

    @property
    def messaging_report(self):
        """Gets the messaging_report of this AnalyticsMessagingReportModel.  # noqa: E501

        The time series messaging report.  # noqa: E501

        :return: The messaging_report of this AnalyticsMessagingReportModel.  # noqa: E501
        :rtype: list[AnalyticsMessagingReportListItemModel]
        """
        return self._messaging_report

    @messaging_report.setter
    def messaging_report(self, messaging_report):
        """Sets the messaging_report of this AnalyticsMessagingReportModel.

        The time series messaging report.  # noqa: E501

        :param messaging_report: The messaging_report of this AnalyticsMessagingReportModel.  # noqa: E501
        :type: list[AnalyticsMessagingReportListItemModel]
        """

        self._messaging_report = messaging_report

    @property
    def unique_active_customers(self):
        """Gets the unique_active_customers of this AnalyticsMessagingReportModel.  # noqa: E501

        Unique active customers over requested timeframe.  # noqa: E501

        :return: The unique_active_customers of this AnalyticsMessagingReportModel.  # noqa: E501
        :rtype: int
        """
        return self._unique_active_customers

    @unique_active_customers.setter
    def unique_active_customers(self, unique_active_customers):
        """Sets the unique_active_customers of this AnalyticsMessagingReportModel.

        Unique active customers over requested timeframe.  # noqa: E501

        :param unique_active_customers: The unique_active_customers of this AnalyticsMessagingReportModel.  # noqa: E501
        :type: int
        """

        self._unique_active_customers = unique_active_customers

    @property
    def unique_active_channels(self):
        """Gets the unique_active_channels of this AnalyticsMessagingReportModel.  # noqa: E501

        Unique active channels over requested timeframe.  # noqa: E501

        :return: The unique_active_channels of this AnalyticsMessagingReportModel.  # noqa: E501
        :rtype: int
        """
        return self._unique_active_channels

    @unique_active_channels.setter
    def unique_active_channels(self, unique_active_channels):
        """Sets the unique_active_channels of this AnalyticsMessagingReportModel.

        Unique active channels over requested timeframe.  # noqa: E501

        :param unique_active_channels: The unique_active_channels of this AnalyticsMessagingReportModel.  # noqa: E501
        :type: int
        """

        self._unique_active_channels = unique_active_channels

    @property
    def unique_active_agents(self):
        """Gets the unique_active_agents of this AnalyticsMessagingReportModel.  # noqa: E501

        Unique active agents over requested timeframe.  # noqa: E501

        :return: The unique_active_agents of this AnalyticsMessagingReportModel.  # noqa: E501
        :rtype: int
        """
        return self._unique_active_agents

    @unique_active_agents.setter
    def unique_active_agents(self, unique_active_agents):
        """Sets the unique_active_agents of this AnalyticsMessagingReportModel.

        Unique active agents over requested timeframe.  # noqa: E501

        :param unique_active_agents: The unique_active_agents of this AnalyticsMessagingReportModel.  # noqa: E501
        :type: int
        """

        self._unique_active_agents = unique_active_agents

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsMessagingReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsMessagingReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ZipwhipOrgChannelModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'phone_number': 'str',
        'fast_bulk_send': 'bool',
        'approved_by': 'str',
        'user_id': 'int'
    }

    attribute_map = {
        'phone_number': 'phoneNumber',
        'fast_bulk_send': 'fastBulkSend',
        'approved_by': 'approvedBy',
        'user_id': 'userId'
    }

    def __init__(self, phone_number=None, fast_bulk_send=None, approved_by=None, user_id=None):  # noqa: E501
        """ZipwhipOrgChannelModel - a model defined in Swagger"""  # noqa: E501
        self._phone_number = None
        self._fast_bulk_send = None
        self._approved_by = None
        self._user_id = None
        self.discriminator = None
        if phone_number is not None:
            self.phone_number = phone_number
        if fast_bulk_send is not None:
            self.fast_bulk_send = fast_bulk_send
        if approved_by is not None:
            self.approved_by = approved_by
        if user_id is not None:
            self.user_id = user_id

    @property
    def phone_number(self):
        """Gets the phone_number of this ZipwhipOrgChannelModel.  # noqa: E501

        The outgoing phone number for this Zipwhip org channel  # noqa: E501

        :return: The phone_number of this ZipwhipOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this ZipwhipOrgChannelModel.

        The outgoing phone number for this Zipwhip org channel  # noqa: E501

        :param phone_number: The phone_number of this ZipwhipOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def fast_bulk_send(self):
        """Gets the fast_bulk_send of this ZipwhipOrgChannelModel.  # noqa: E501

        Enable Fast Bulk Send  # noqa: E501

        :return: The fast_bulk_send of this ZipwhipOrgChannelModel.  # noqa: E501
        :rtype: bool
        """
        return self._fast_bulk_send

    @fast_bulk_send.setter
    def fast_bulk_send(self, fast_bulk_send):
        """Sets the fast_bulk_send of this ZipwhipOrgChannelModel.

        Enable Fast Bulk Send  # noqa: E501

        :param fast_bulk_send: The fast_bulk_send of this ZipwhipOrgChannelModel.  # noqa: E501
        :type: bool
        """

        self._fast_bulk_send = fast_bulk_send

    @property
    def approved_by(self):
        """Gets the approved_by of this ZipwhipOrgChannelModel.  # noqa: E501

        Person approved the Zhipwhip org channel  # noqa: E501

        :return: The approved_by of this ZipwhipOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._approved_by

    @approved_by.setter
    def approved_by(self, approved_by):
        """Sets the approved_by of this ZipwhipOrgChannelModel.

        Person approved the Zhipwhip org channel  # noqa: E501

        :param approved_by: The approved_by of this ZipwhipOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._approved_by = approved_by

    @property
    def user_id(self):
        """Gets the user_id of this ZipwhipOrgChannelModel.  # noqa: E501

        The user id make this request  # noqa: E501

        :return: The user_id of this ZipwhipOrgChannelModel.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ZipwhipOrgChannelModel.

        The user id make this request  # noqa: E501

        :param user_id: The user_id of this ZipwhipOrgChannelModel.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ZipwhipOrgChannelModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ZipwhipOrgChannelModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsOptOutReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp_epoch': 'int',
        'customer_name': 'str',
        'customer_phone': 'str',
        'org_channel_name': 'str',
        'org_channel_value': 'str',
        'status': 'str',
        'type': 'str',
        'customer_id': 'int'
    }

    attribute_map = {
        'timestamp_epoch': 'timestampEpoch',
        'customer_name': 'customerName',
        'customer_phone': 'customerPhone',
        'org_channel_name': 'orgChannelName',
        'org_channel_value': 'orgChannelValue',
        'status': 'status',
        'type': 'type',
        'customer_id': 'customerId'
    }

    def __init__(self, timestamp_epoch=None, customer_name=None, customer_phone=None, org_channel_name=None, org_channel_value=None, status=None, type=None, customer_id=None):  # noqa: E501
        """AnalyticsOptOutReportModel - a model defined in Swagger"""  # noqa: E501
        self._timestamp_epoch = None
        self._customer_name = None
        self._customer_phone = None
        self._org_channel_name = None
        self._org_channel_value = None
        self._status = None
        self._type = None
        self._customer_id = None
        self.discriminator = None
        if timestamp_epoch is not None:
            self.timestamp_epoch = timestamp_epoch
        if customer_name is not None:
            self.customer_name = customer_name
        if customer_phone is not None:
            self.customer_phone = customer_phone
        if org_channel_name is not None:
            self.org_channel_name = org_channel_name
        if org_channel_value is not None:
            self.org_channel_value = org_channel_value
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if customer_id is not None:
            self.customer_id = customer_id

    @property
    def timestamp_epoch(self):
        """Gets the timestamp_epoch of this AnalyticsOptOutReportModel.  # noqa: E501

        The timestamp of the Opt-In or Opt-Out event as a Unix timestamp.  # noqa: E501

        :return: The timestamp_epoch of this AnalyticsOptOutReportModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp_epoch

    @timestamp_epoch.setter
    def timestamp_epoch(self, timestamp_epoch):
        """Sets the timestamp_epoch of this AnalyticsOptOutReportModel.

        The timestamp of the Opt-In or Opt-Out event as a Unix timestamp.  # noqa: E501

        :param timestamp_epoch: The timestamp_epoch of this AnalyticsOptOutReportModel.  # noqa: E501
        :type: int
        """

        self._timestamp_epoch = timestamp_epoch

    @property
    def customer_name(self):
        """Gets the customer_name of this AnalyticsOptOutReportModel.  # noqa: E501

        The display name of the customer who opted-in or opted-out.  # noqa: E501

        :return: The customer_name of this AnalyticsOptOutReportModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this AnalyticsOptOutReportModel.

        The display name of the customer who opted-in or opted-out.  # noqa: E501

        :param customer_name: The customer_name of this AnalyticsOptOutReportModel.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def customer_phone(self):
        """Gets the customer_phone of this AnalyticsOptOutReportModel.  # noqa: E501

        The phone number of the customer who opted-in or opted-out.  # noqa: E501

        :return: The customer_phone of this AnalyticsOptOutReportModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_phone

    @customer_phone.setter
    def customer_phone(self, customer_phone):
        """Sets the customer_phone of this AnalyticsOptOutReportModel.

        The phone number of the customer who opted-in or opted-out.  # noqa: E501

        :param customer_phone: The customer_phone of this AnalyticsOptOutReportModel.  # noqa: E501
        :type: str
        """

        self._customer_phone = customer_phone

    @property
    def org_channel_name(self):
        """Gets the org_channel_name of this AnalyticsOptOutReportModel.  # noqa: E501

        The display name of the org channel that the Opt-In or Opt-Out event came through on.  # noqa: E501

        :return: The org_channel_name of this AnalyticsOptOutReportModel.  # noqa: E501
        :rtype: str
        """
        return self._org_channel_name

    @org_channel_name.setter
    def org_channel_name(self, org_channel_name):
        """Sets the org_channel_name of this AnalyticsOptOutReportModel.

        The display name of the org channel that the Opt-In or Opt-Out event came through on.  # noqa: E501

        :param org_channel_name: The org_channel_name of this AnalyticsOptOutReportModel.  # noqa: E501
        :type: str
        """

        self._org_channel_name = org_channel_name

    @property
    def org_channel_value(self):
        """Gets the org_channel_value of this AnalyticsOptOutReportModel.  # noqa: E501

        The phone number of the org channel that the Opt-In or Opt-Out event came through on.  # noqa: E501

        :return: The org_channel_value of this AnalyticsOptOutReportModel.  # noqa: E501
        :rtype: str
        """
        return self._org_channel_value

    @org_channel_value.setter
    def org_channel_value(self, org_channel_value):
        """Sets the org_channel_value of this AnalyticsOptOutReportModel.

        The phone number of the org channel that the Opt-In or Opt-Out event came through on.  # noqa: E501

        :param org_channel_value: The org_channel_value of this AnalyticsOptOutReportModel.  # noqa: E501
        :type: str
        """

        self._org_channel_value = org_channel_value

    @property
    def status(self):
        """Gets the status of this AnalyticsOptOutReportModel.  # noqa: E501

        The resulting status (true if customer has opted-out, false if customer has opted back in).  # noqa: E501

        :return: The status of this AnalyticsOptOutReportModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AnalyticsOptOutReportModel.

        The resulting status (true if customer has opted-out, false if customer has opted back in).  # noqa: E501

        :param status: The status of this AnalyticsOptOutReportModel.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def type(self):
        """Gets the type of this AnalyticsOptOutReportModel.  # noqa: E501

        The event type ().  # noqa: E501

        :return: The type of this AnalyticsOptOutReportModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AnalyticsOptOutReportModel.

        The event type ().  # noqa: E501

        :param type: The type of this AnalyticsOptOutReportModel.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def customer_id(self):
        """Gets the customer_id of this AnalyticsOptOutReportModel.  # noqa: E501

        The customerId of the customer who opted-in or opted-out.  # noqa: E501

        :return: The customer_id of this AnalyticsOptOutReportModel.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this AnalyticsOptOutReportModel.

        The customerId of the customer who opted-in or opted-out.  # noqa: E501

        :param customer_id: The customer_id of this AnalyticsOptOutReportModel.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsOptOutReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsOptOutReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.conversations_api import ConversationsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestConversationsApi(unittest.TestCase):
    """ConversationsApi unit test stubs"""

    def setUp(self):
        self.api = ConversationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_conversation(self):
        """Test case for add_conversation

        Creates a conversation with customer and the team member  # noqa: E501
        """
        pass

    def test_assign(self):
        """Test case for assign

        Takes a conversation and assigns it to one or more groups/users  # noqa: E501
        """
        pass

    def test_assign_bot(self):
        """Test case for assign_bot

        Takes a conversation and assigns it to a bot  # noqa: E501
        """
        pass

    def test_close(self):
        """Test case for close

        Closes the requested conversation  # noqa: E501
        """
        pass

    def test_escalate(self):
        """Test case for escalate

        Takes an active conversation handled by a bot, and escalates it to groups or teamMembers  # noqa: E501
        """
        pass

    def test_get_active(self):
        """Test case for get_active

        Gets all the active conversations for a team member  # noqa: E501
        """
        pass

    def test_get_active_for_bot(self):
        """Test case for get_active_for_bot

        Gets all the active conversations for a bot  # noqa: E501
        """
        pass

    def test_get_active_for_customer(self):
        """Test case for get_active_for_customer

        Gets all the active conversations for a customer  # noqa: E501
        """
        pass

    def test_get_active_for_customer_by_channel_id(self):
        """Test case for get_active_for_customer_by_channel_id

        Gets all the active conversations for a customer  # noqa: E501
        """
        pass

    def test_get_active_for_customer_by_channel_key(self):
        """Test case for get_active_for_customer_by_channel_key

        Gets all the active conversations for a customer  # noqa: E501
        """
        pass

    def test_get_conversation(self):
        """Test case for get_conversation

        Gets a conversation based on its internal id.  # noqa: E501
        """
        pass

    def test_get_conversation_messages(self):
        """Test case for get_conversation_messages

        Gets messages for a conversation  # noqa: E501
        """
        pass

    def test_get_for_customer(self):
        """Test case for get_for_customer

        Gets all messages for a customer, as visible by a team member  # noqa: E501
        """
        pass

    def test_get_inbox(self):
        """Test case for get_inbox

        Gets all the conversations in the team members inbox.  # noqa: E501
        """
        pass

    def test_get_smart_link(self):
        """Test case for get_smart_link

        Creates a smart link for the customer involved in the conversation  # noqa: E501
        """
        pass

    def test_opt_out(self):
        """Test case for opt_out

        Opted out customers can not receive any additional messages from this conversations until opted back in  # noqa: E501
        """
        pass

    def test_post_message(self):
        """Test case for post_message

        Posts a message to an active conversation  # noqa: E501
        """
        pass

    def test_post_whisper(self):
        """Test case for post_whisper

        Posts a whisper to an active conversation  # noqa: E501
        """
        pass

    def test_remove_team_member_from_conversation(self):
        """Test case for remove_team_member_from_conversation

        Removes a team member from a conversation.  # noqa: E501
        """
        pass

    def test_take(self):
        """Test case for take

        Takes a pending conversation and moves it into an active state, ready for communication  # noqa: E501
        """
        pass

    def test_update_membership(self):
        """Test case for update_membership

        Updates the team members presences in conversation, optionally add it to their Inbox, Active Chats, or removing it altogether  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
